SELECT
    URLHash,
    EventDate,
    COUNT(*) AS PageViews
FROM
    hits
WHERE
    CounterID = 62
    AND EventDate >= '2013-07-01'
    AND EventDate <= '2013-07-31'
    AND IsRefresh = 0
    AND TraficSourceID IN (-1, 6)
    AND RefererHash = 3594120000172545465
GROUP BY
    URLHash,
    EventDate
ORDER BY
    PageViews DESC
LIMIT
    10 OFFSET 100;